/************************************************************************/
/*																		*/
/*	GPIO_demo.h	--	Interface Declarations for GPIO_Demo.c				*/
/*																		*/
/************************************************************************/
/*	Author:	Sam Bobrowicz												*/
/*	Copyright 2011, Digilent Inc.										*/
/************************************************************************/
/*  File Description: 													*/
/*																		*/
/*	This Header file contains the interface and constant definitions	*/
/*	used by GPIO_demo.c. GPIO_demo is a reference project that 			*/
/*	demonstrates a simple usage of the Nexys3's GPIO and UART in an EDK	*/
/*	design.																*/
/*																		*/
/************************************************************************/
/*  Revision History:													*/
/* 																		*/
/*		7/29/2011(SamB): Created										*/
/*		3/12/2013(SamB): Updated to use svn_seg_axi core and document   */
/*						 it register map.								*/
/*																		*/
/************************************************************************/

#ifndef GPIO_DEMO_H
#define GPIO_DEMO_H

/* ------------------------------------------------------------ */
/*					Constant Definitions						*/
/* ------------------------------------------------------------ */


#define lBtnChannel	1//GPIO channel of the push buttons

/*
 * Writing this value to the timer control register (TCSR0)
 * clears the interrupt flag
 */
#define bitTmrIntClr 0x00000100

/*
 * Writing this value to TCSR0 of the timer starts the counter at the
 * value stored in TLR0, counting down in generate mode with Auto Reload.
 * This means that when 0 is reached an interrupt will be triggered, and
 * then the value stored in TLR0 will be reloaded and the count down will
 * begin again.
 */
#define fsTmrRun 0x000000D2

/*
 * Writing this value to TCSR0 sets the counter to the value of TLR0
 */
#define bitTmrLoad 0x00000020

/*
 * This is the value that the counter counts down from. With a 83.33 MHz
 * clock, it will cause an interrupt to occur approximately ever second.
 */
#define lTmrLoadVal 0x04F790D5

/*
 * Register offsets for the timer core control registers, from its base
 * address
 */
#define bTmrTCSR0 0x00
#define bTmrTLR0 0x04

/*
 * Register offsets for the seven segment core control registers, from its base
 * address
 */

//HEX_DATA_REG
//  bit [15:0] -> Data Input = Hex data to be displayed
#define bSsgHexData 0x00

//CTRL_REG
//  bit [3:0]   -> Blank = Blank signal for each anode (will make that particular digit blank: if you want to blank digit no. 3 then Blank = 4'b0001)
//  bit [4]     -> Autoblank = Automatically blank the most significant digits when in Hex Mode (if the value to display is 0x0034 then it will display 0x  34)
//  bit [5]     -> Use Segment Data = Enables usage of seven segment data instead of Hex data
//  bit [11:8]  -> Blink = Enables blinking, for each anode (if you want to blink digit no. 3 then Blink = 4'b0001)
//  bit [18:16] -> Blink Rate = Blinking rate
#define bSsgCtrl 0x04

//SEGMENT_REG
//  bit [0:31] -> Segment Data = Segment data for each digit, including decimal point:
//	 - bits [0], [8], [16], [24] -> digit 0 dp, digit 1 dp, digit 2 dp, digit 3 dp
//	 - bits [1:7], [9:15], [17:23], [25:31] -> digit 0 data, digit 1 data, digit 2 data, digit 3 data
#define bSsgSeg 0x08

//REFRESH_DIV_REG
//  bit [8:31] -> Refresh Rate = Division rate for the refresh rate (default value, 0x1046A,  is typically acceptable)
#define bSsgDiv 0x0C

/*
 * Mask for the blanking region of the Seven Segment display controller
 */
#define mskSsgBlank 0x0000000F


/* ------------------------------------------------------------ */
/*					Procedure Declarations						*/
/* ------------------------------------------------------------ */


void PushBtnHandler(void *CallBackRef);
void TmrHandler(void *CallBackRef);
void InitIrpts();


/* ------------------------------------------------------------ */
#endif
/************************************************************************/
